Introduction
============

Overview
--------

five.localsitemanager attempts to provide a local site manager implementation
that is as close to the zope.interface / zope.component implementation as
possible. Some reservations that do not conflict with the original API have
been made to ease the path with CMF.

Developer Resources
-------------------

- Source code:

  https://github.com/zopefoundation/five.localsitemanager
